==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/eventing/v1/TriggerSpecBuilder.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class TriggerSpecBuilder extends TriggerSpecFluentImpl<TriggerSpecBuilder> implements VisitableBuilder<TriggerSpec,TriggerSpecBuilder> {

    TriggerSpecFluent<?> fluent;
    Boolean validationEnabled;

    public TriggerSpecBuilder() { 
        this(true);
    }


    public TriggerSpecBuilder(Boolean validationEnabled) { 
        this(new TriggerSpec(), validationEnabled);
    }


    public TriggerSpecBuilder(TriggerSpecFluent<?> fluent) { 
        this(fluent, true);
    }


    public TriggerSpecBuilder(TriggerSpecFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new TriggerSpec(), validationEnabled);
    }


    public TriggerSpecBuilder(TriggerSpecFluent<?> fluent,TriggerSpec instance) { 
        this(fluent, instance, true);
    }


    public TriggerSpecBuilder(TriggerSpecFluent<?> fluent,TriggerSpec instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withBroker(instance.getBroker()); 
        fluent.withFilter(instance.getFilter()); 
        fluent.withSubscriber(instance.getSubscriber()); 
        this.validationEnabled = validationEnabled; 
    }


    public TriggerSpecBuilder(TriggerSpec instance) { 
        this(instance,true);
    }


    public TriggerSpecBuilder(TriggerSpec instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withBroker(instance.getBroker()); 
        this.withFilter(instance.getFilter()); 
        this.withSubscriber(instance.getSubscriber()); 
        this.validationEnabled = validationEnabled; 
    }


    public TriggerSpec build() {
        TriggerSpec buildable = new TriggerSpec(fluent.getBroker(),fluent.getFilter(),fluent.getSubscriber());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        TriggerSpecBuilder that = (TriggerSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/v1/TriggerSpecBuilder.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class TriggerSpecBuilder extends TriggerSpecFluentImpl<TriggerSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<TriggerSpec,TriggerSpecBuilder> {

    TriggerSpecFluent<?> fluent;
    Boolean validationEnabled;

    public TriggerSpecBuilder() {
        this(true);
    }

    public TriggerSpecBuilder(Boolean validationEnabled) {
        this(new TriggerSpec(), validationEnabled);
    }

    public TriggerSpecBuilder(TriggerSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public TriggerSpecBuilder(TriggerSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new TriggerSpec(), validationEnabled);
    }

    public TriggerSpecBuilder(TriggerSpecFluent<?> fluent,TriggerSpec instance) {
        this(fluent, instance, true);
    }

    public TriggerSpecBuilder(TriggerSpecFluent<?> fluent,TriggerSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withBroker(instance.getBroker()); 
        fluent.withFilter(instance.getFilter()); 
        fluent.withSubscriber(instance.getSubscriber()); 
        this.validationEnabled = validationEnabled; 
    }

    public TriggerSpecBuilder(TriggerSpec instance) {
        this(instance,true);
    }

    public TriggerSpecBuilder(TriggerSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withBroker(instance.getBroker()); 
        this.withFilter(instance.getFilter()); 
        this.withSubscriber(instance.getSubscriber()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.v1.EditableTriggerSpec build() {
        EditableTriggerSpec buildable = new EditableTriggerSpec(fluent.getBroker(),fluent.getFilter(),fluent.getSubscriber());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        TriggerSpecBuilder that = (TriggerSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
